/**
	$Id: WebClientRegisterExtensionsProcessor.java 5603 2011-04-08 12:50:27Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions;

import net.sf.basedb.util.extensions.manager.ExtensionsFile;
import net.sf.basedb.util.extensions.manager.ExtensionsManager;
import net.sf.basedb.util.extensions.manager.ProcessResults;
import net.sf.basedb.util.extensions.manager.ExtensionsFile.WriteableExtensionsFile;
import net.sf.basedb.util.extensions.manager.processor.RegisterExtensionsProcessor;
import net.sf.basedb.util.extensions.xml.PathConverter;
import net.sf.basedb.util.extensions.xml.VariableConverter;
import net.sf.basedb.util.extensions.xml.XmlLoader;

/**
	A subclass to the regular extensions processor that adds information
	about various paths (eg. home path, servlet path) on the web client 
	as variables in the XmlLoader that is used to process the definition
	files. This is need so that factory parameters can contain relative 
	URL:s.

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-08 14:50:27 +0200 (Fri, 08 Apr 2011) $
*/
public class WebClientRegisterExtensionsProcessor
	extends RegisterExtensionsProcessor
{

	private final VariableConverter variableConverter;
	private final PathConverter pathConverter;
	private final String resourcesPath;
	private final String servletsPath;
	
	public WebClientRegisterExtensionsProcessor(String rootPath, String resourcesPath, String servletsPath, ProcessResults results)
	{
		super(new XmlLoader(), results);
		
		setDelayRegistration(true);
		
		this.resourcesPath = resourcesPath;
		this.servletsPath = servletsPath;
		
		// Create path converters, etc.
		variableConverter = new VariableConverter();
		variableConverter.setVariable("ROOT", rootPath);
		variableConverter.setVariable("HOME", resourcesPath);
		variableConverter.setVariable("SERVLET_HOME", servletsPath);		
		pathConverter = new PathConverter(rootPath, resourcesPath);
		
		XmlLoader loader = getXmlLoader();
		loader.addValueConverter(pathConverter);
		loader.addValueConverter(variableConverter);
	}
	
	/*
		From the RegisterExtensionsProcessor class
		------------------------------------------
	*/
	@Override
	public void processFile(ExtensionsManager manager, WriteableExtensionsFile wFile)
	{
		ExtensionsFile xtFile = wFile.getExtensionsFile();
		String resourcesHome = resourcesPath + "/" + xtFile.getName();
		String servletHome = servletsPath + "/" + xtFile.getName();
		variableConverter.setVariable("HOME", resourcesHome);
		variableConverter.setVariable("SERVLET_HOME", servletHome);
		pathConverter.setHome(resourcesHome);
		super.processFile(manager, wFile);
	}
	// ------------------------------------------


}
