/**
	$Id:CompactButtonRenderer.java 4187 2008-03-20 11:15:25Z nicklas $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.extensions.toolbar;

import java.io.IOException;
import java.io.Writer;

import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.util.HTML;
import net.sf.basedb.util.extensions.Renderer;

/**
	A compact renderer for toolbar button actions, which only
	only displays the icon. 

	@author nicklas
	@version 2.7
	@base.modified $Date:2008-03-20 12:15:25 +0100 (Thu, 20 Mar 2008) $
 */
public class CompactButtonRenderer
	implements Renderer<ButtonAction>
{

	private JspContext context;
	
	public CompactButtonRenderer(JspContext context)
	{
		this.context = context;
	}
	
	/**
		Generates a linked icon: 
		<pre class="code">
<a 
   id="[id]" 
   class="[clazz]"
   style="[style]" 
   href="javascript:[onClick]" 
   title="[title]: [tooltip]"
><img src="[icon]"></a>
</pre>

		If the button isn't visible nothing is generated. If the button isn't enabled,
		the href attribute is not generated.
	*/
	public void render(ButtonAction btn)
	{
		if (!btn.isVisible()) return;
		Writer out = context.getOut();
		try
		{
			out.write("<a");
			if (btn.getId() != null) out.write(" id=\"" + btn.getId() + "\"");
			if (btn.getClazz() != null) out.write(" class=\"" + btn.getClazz() + "\"");
			if (btn.getStyle() != null) out.write(" style=\"" + btn.getStyle() + "\"");
			if (btn.isEnabled() && btn.getOnClick() != null) 
			{
				out.write(" href=\"javascript:" + btn.getOnClick() + "\"");
				if (btn.getTabIndex() >= 0) 
				{
					out.write(" tabindex=\""+btn.getTabIndex()+"\"");
				}
			}
			String title = btn.getTitle();
			if (btn.getTooltip() != null)
			{
				title = title == null ? btn.getTooltip() : title + ": " + btn.getTooltip();
			}
			if (title != null) out.write(" title=\"" + HTML.encodeTags(title) + "\"");
			out.write("><img");
			if (btn.getIcon() != null) out.write(" src=\"" + btn.getIcon() + "\"");
			out.write("></a>\n");
		}
		catch (IOException ex)
		{
			throw new RuntimeException(ex);
		}
	}

}
