/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.web.formatter;

import net.sf.basedb.clients.web.util.HTML;
import net.sf.basedb.util.formatter.Formatter;

/**
	Nicely format a string for output on a web page. This means that the string is
	encoded by one of the {@link HTML#niceFormat(String)} methods to prevent pollution
	of the generated HTML.

	@author nicklas
	@since 3.2
	@base.modified $Date$
*/
public class NiceFormatter
	implements Formatter<String>
{

	private int flags;
	
	/**
		Create a new formatter with default options:
		{@link HTML#LINK_EMAIL} + {@link HTML#LINK_URL} + {@link HTML#SMART_IMAGES}
	*/
	public NiceFormatter()
	{
		this(HTML.LINK_EMAIL + HTML.LINK_URL + HTML.SMART_IMAGES);
	}
	
	/**
		Create a new formatter with options.
		
		@param flags The flags to use when formatting
		@see HTML#niceFormat(String, int)
	*/
	public NiceFormatter(int flags)
	{
		this.flags = flags;
	}
	
	/*
		From the Formatter interface
		-------------------------------------------
	*/
	public String format(String value)
	{
		return value == null ? "" : HTML.niceFormat(value, flags);
	}
	public String parseString(String value)
	{
		return value;
	}
	// -------------------------------------------

}
