/**
	$Id: DropDynamicTableAction.java 5877 2011-11-16 14:39:47Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	Transactional action that can drop a table from the dynamic database
	after a successful commit and/or rollback.
	
	@author Nicklas
	@since 3.1
	@base.modified $Date: 2011-11-16 15:39:47 +0100 (Wed, 16 Nov 2011) $
*/
class DropDynamicTableAction
	implements TransactionalAction
{

	
	private final String tableName;
	private final boolean atCommit;
	private final boolean atRollback;
	
	/**
		Create a new drop table action.
		
		@param tableName The name of the dynamic table that should be dropped
		@param atCommit If TRUE, the table should be dropped after a successful commit
		@param atRollback If TRUE, the table should be dropped after a rollback
	*/
	DropDynamicTableAction(String tableName, boolean atCommit, boolean atRollback)
	{
		this.tableName = tableName;
		this.atCommit = atCommit;
		this.atRollback = atRollback;
	}
	
	/*
		From the TransactionalAction interface
		--------------------------------------
	*/
	@Override
	public void onBeforeCommit()
	{}

	@Override
	public void onAfterCommit()
	{
		if (atCommit) HibernateUtil.dropDynamicTable(tableName);
	}

	@Override
	public void onRollback()
	{
		if (atRollback) HibernateUtil.dropDynamicTable(tableName);
	}
	// --------------------------------------

}
