/**
	$Id: TableInfoWork.java 4517 2008-09-11 20:11:02Z jari $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.hibernate;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;

import org.hibernate.mapping.Table;

import net.sf.basedb.core.dbengine.TableInfo;

/**
	A work implementation that loads database metadata for a table
	and returns it as a {@link TableInfo} object.

	@author nicklas
	@version 2.9
	@base.modified $Date: 2008-09-11 22:11:02 +0200 (Thu, 11 Sep 2008) $
*/
public class TableInfoWork
	implements JdbcWork<TableInfo>
{

	private final Table table;
	private TableInfo info;
	
	/**
		Create a new work item.
		@param table The table to get metadata information about
	 */
	public TableInfoWork(Table table)
	{
		this.table = table;
	}
	
	/**
		From the Work interface
		-----------------------
	*/
	@Override
	public void execute(Connection connection) 
		throws SQLException
	{
		DatabaseMetaData metaData = connection.getMetaData();
		info = new TableInfo(table, metaData);
	}
	// --------------------------
	
	/*
		From the JdbcWork interface
		---------------------------
	*/
	@Override
	public TableInfo getResult()
	{
		return info;
	}
	// ----------------------------

}
