/**
	$Id: AnnotationLogger.java 6080 2012-08-07 11:28:40Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import org.hibernate.Hibernate;
import org.hibernate.Query;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.LogControl;
import net.sf.basedb.core.PredefinedQuery;
import net.sf.basedb.core.data.AnnotationData;
import net.sf.basedb.core.data.AnnotationSetData;
import net.sf.basedb.core.data.AnnotationTypeData;
import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.data.LoggableData;
import net.sf.basedb.core.log.EntityDetails;
import net.sf.basedb.core.log.ChangeType;
import net.sf.basedb.core.log.EntityLogger;
import net.sf.basedb.core.log.LogManager;

/**
	Logger for annotations that logs changes as
	updates to the parent item the annotations belong to.
	
	@author Nicklas
	@version 2.13
	@base.modified $Date: 2012-08-07 13:28:40 +0200 (Tue, 07 Aug 2012) $
*/
public class AnnotationLogger
	implements EntityLogger
{

	public AnnotationLogger()
	{}
	
	/*
		From the EntityLogger interface
		-------------------------------
	*/
	@Override
	public void logChanges(LogManager logManager, EntityDetails details)
	{
		LogControl logControl = logManager.getLogControl();
		AnnotationData annotation = (AnnotationData)details.getEntity();
		
		// Get the name of the annotation type
		String annotationType = null;
		AnnotationTypeData at = annotation.getAnnotationType();
		if (!Hibernate.isInitialized(at))
		{
			Query q = logControl.createHqlQuery(
					PredefinedQuery.getQueryString("DBLOG_GET_ANNOTATIONTYPE_NAME"));
			q.setInteger("annotationTypeId", at.getId());
			annotationType = (String)q.uniqueResult();
		}
		else
		{
			annotationType = at.getName();
		}
		
		// Get the type of the parent item
		AnnotationSetData as = annotation.getAnnotationSet();
		Integer itemType = null;
		if (!Hibernate.isInitialized(as))
		{
			Query q = logControl.createHqlQuery(
				PredefinedQuery.getQueryString("DBLOG_GET_ANNOTATION_ITEMTYPE"));
			q.setInteger("annotationSetId", as.getId());
			itemType = (Integer)q.uniqueResult();			
		}
		else
		{
			itemType = as.getItemType();
		}
		
		// May happen in case the annotation set has been deleted in this transaction
		if (itemType == null) return;
		
		Class parentClass = Item.fromValue(itemType).getDataClass();
		// If the parent item isn't implementing the LoggableData interface
		// we don't log the changes
		if (!LoggableData.class.isAssignableFrom(parentClass)) return;
		
		// Get the id of the parent item
		Query q = logControl.createHqlQuery(
			PredefinedQuery.getQueryString("DBLOG_GET_ITEMID_WITH_ANNOTATION", parentClass.getName()));
		q.setInteger("annotationSetId", as.getId());
		Integer parentId = (Integer)q.uniqueResult();
		
		// May happen in case the parent item has been deleted in this transaction
		if (parentId == null) return;
		
		ChangeHistoryDetailData change = new ChangeHistoryDetailData();
		change.setChangeType(ChangeType.UPDATE.getValue());
		change.setItemId(parentId);
		change.setItemType(itemType);
		change.setChangeInfo(details.getChangeType().was("Annotation") + ": " + annotationType);
		((DbLogManager)logManager).logChangeDetails(change, details);
	}
	// -------------------------------
}
