/**
	$Id: FileSetMemberLogger.java 6080 2012-08-07 11:28:40Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.log.db;

import org.hibernate.Hibernate;
import org.hibernate.Query;

import net.sf.basedb.core.Item;
import net.sf.basedb.core.LogControl;
import net.sf.basedb.core.PredefinedQuery;
import net.sf.basedb.core.data.ChangeHistoryDetailData;
import net.sf.basedb.core.data.DataFileTypeData;
import net.sf.basedb.core.data.FileSetData;
import net.sf.basedb.core.data.FileSetMemberData;
import net.sf.basedb.core.log.EntityDetails;
import net.sf.basedb.core.log.ChangeType;
import net.sf.basedb.core.log.EntityLogger;
import net.sf.basedb.core.log.LogManager;

/**
	Logger for file set members that logs changes as
	updates to the parent item the file belong to.
	
	@author Nicklas
	@version 2.13
	@base.modified $Date: 2012-08-07 13:28:40 +0200 (Tue, 07 Aug 2012) $
*/
public class FileSetMemberLogger
	implements EntityLogger
{

	public FileSetMemberLogger()
	{}
	
	/*
		From the EntityLogger interface
		-------------------------------
	*/
	@Override
	public void logChanges(LogManager logManager, EntityDetails details)
	{
		LogControl logControl = logManager.getLogControl();
		FileSetMemberData member = (FileSetMemberData)details.getEntity();
		
		// Get the name of the data file type
		String fileType = null;
		DataFileTypeData ft = member.getDataFileType();
		if (!Hibernate.isInitialized(ft))
		{
			Query q = logControl.createHqlQuery(
					PredefinedQuery.getQueryString("DBLOG_GET_DATAFILETYPE_NAME"));
			q.setInteger("dataFileTypeId", ft.getId());
			fileType = (String)q.uniqueResult();
		}
		else
		{
			fileType = ft.getName();
		}
		
		// Get the type of the parent item
		FileSetData fs = member.getFileSet();
		Integer itemType = null;
		if (!Hibernate.isInitialized(fs))
		{
			Query q = logControl.createHqlQuery(
				PredefinedQuery.getQueryString("DBLOG_GET_FILESET_ITEMTYPE"));
			q.setInteger("fileSetId", fs.getId());
			itemType = (Integer)q.uniqueResult();			
		}
		else
		{
			itemType = fs.getItemType();
		}
		
		// May happen in case the file set has been deleted in this transaction
		if (itemType == null) return;
		
		// Get the id of the parent item
		String parentClass = Item.fromValue(itemType).getDataClass().getName();
		Query q = logControl.createHqlQuery(
			PredefinedQuery.getQueryString("DBLOG_GET_ITEMID_WITH_FILESET", parentClass));
		q.setInteger("fileSetId", fs.getId());
		Integer parentId = (Integer)q.uniqueResult();
		
		// May happen in case the parent item has been deleted in this transaction
		if (parentId == null) return;
		
		ChangeHistoryDetailData change = new ChangeHistoryDetailData();
		change.setChangeType(ChangeType.UPDATE.getValue());
		change.setItemId(parentId);
		change.setItemType(itemType);
		change.setChangeInfo(details.getChangeType().was("File") + ": " + fileType);
		((DbLogManager)logManager).logChangeDetails(change, details);
	}
	// -------------------------------
}
