/*
	$Id: BooleanExpression.java 5897 2011-12-02 11:09:46Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.query;

import java.util.Collection;
import java.util.Collections;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.HibernateUtil;

/**
	A constant boolean expression.
	
	@author Nicklas
	@since 3.1
	@see Expressions#bool(boolean)
	@base.modified $Date: 2011-12-02 12:09:46 +0100 (Fri, 02 Dec 2011) $
*/
public class BooleanExpression
	implements Expression
{
	private final boolean value;
	private final Restriction r;

	BooleanExpression(boolean value)
	{
		this.value = value;
		this.r = null;
	}
	
	BooleanExpression(Restriction r)
	{
		this.r = r;
		this.value = false;
	}

	/*
		From the QueryElement interface
		-------------------------------------------
	*/
	public String toQl(Query query, DbControl dc)
		throws BaseException
	{
		return r == null ? HibernateUtil.getDialect().toBooleanValueString(value) : r.toQl(query, dc);
	}
	/**
		@return Always null
	*/
	public Collection<? extends QueryElement> getChildren()
	{
		return r == null ? null : Collections.singleton(r);
	}
	// -------------------------------------------
	/*
		From the Object class
		-------------------------------------------
	*/
	@Override
	public String toString()
	{
		return r == null ? Boolean.toString(value) : r.toString();
	}
	/**
		This expression is equal to another BooleanExpression if their 
		values or restrictions are equal.
	*/
	@Override
	public boolean equals(Object other)
	{
		if (this == other) return true;
		if (other == null || this.getClass() != other.getClass()) return false;
		BooleanExpression o = (BooleanExpression)other;
		return r == null ? (this.value == o.value) : r.equals(o.r);
	}
	@Override
	public int hashCode()
	{
		return r == null ? (value ? 1 : 0) : r.hashCode();
	}
	// -------------------------------------------
}
