/**
	$Id: BaseInputStreamLocator.java 5225 2010-01-29 13:34:03Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.bfs;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Directory;
import net.sf.basedb.core.File;

/**
	Input stream locator implementation that works with files within a given
	directory in the BASE file system. The files must be located in the
	specified root directory. Subdirectories or parent paths are not
	supported.

	@author Nicklas
	@version 2.15
	@base.modified $Date: 2010-01-29 14:34:03 +0100 (Fri, 29 Jan 2010) $
*/
public class BaseInputStreamLocator
	implements InputStreamLocator
{

	private final DbControl dc;
	private final Directory dir;
	private final Map<String, File> cache;

	/**
		Create a new input stream locator.
		@param dc A DbControl to use for database access
		@param dir The directory in the BASE file system in which the
			files should be located
	*/
	public BaseInputStreamLocator(DbControl dc, Directory dir)
	{
		if (dir == null) throw new NullPointerException("dir");
		this.dc = dc;
		this.dir = dir;
		this.cache = new HashMap<String, File>();
	}
	
	/**
		Finds and opens an input stream to the file with the given filename.
	*/
	@Override
	public InputStream getInputStream(String filename) 
		throws IOException
	{
		return getFile(filename).getDownloadStream(0);
	}

	@Override
	public long getSize(String filename)
	{
		return getFile(filename).getSize();
	}
	
	private File getFile(String filename)
	{
		File f = cache.get(filename);
		if (f == null)
		{
			f = File.getFile(dc, dir, filename, false);
			cache.put(filename, f);
		}
		return f;
	}

}
