/**
	$Id: ValidAndNewOrModifiedFilter.java 5616 2011-04-27 09:27:56Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager.filter;

import net.sf.basedb.util.extensions.manager.ExtensionsFile;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation for extension files that 
	allow valid and new or modified files to pass.
	The allowUnmodified parameter can be set to also 
	allow unmodified files to pass.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-27 11:27:56 +0200 (Wed, 27 Apr 2011) $
*/
public class ValidAndNewOrModifiedFilter
	implements Filter<ExtensionsFile>
{
	
	private static final org.apache.log4j.Logger log = 
		org.apache.log4j.LogManager.getLogger("net.sf.basedb.util.extensions.manager.filter.ValidAndNewOrModifiedFilter");

	private final boolean allowUnmodified;
	private final Filter<ExtensionsFile> parent;
	
	/**
		Create a new filter.
		
		@param allowUnmodified TRUE to allow unmodified files to 
			pass the filter, FALSE to block them
	*/
	public ValidAndNewOrModifiedFilter(boolean allowUnmodified)
	{
		this(allowUnmodified, null);
	}
	
	/**
		Create a new filter.
		
		@param allowUnmodified TRUE to allow unmodified files to 
			pass the filter, FALSE to block them
		@param parent An optional parent filter that will also be checked
	*/
	public ValidAndNewOrModifiedFilter(boolean allowUnmodified, Filter<ExtensionsFile> parent)
	{
		this.allowUnmodified = allowUnmodified;
		this.parent = parent;
	}
	
	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(ExtensionsFile xtFile)
	{
		if (parent != null && !parent.evaluate(xtFile)) 
		{
			return false;
		}
		
		if (!xtFile.isValid() || (xtFile.hasError() && !allowUnmodified)) 
		{
			log.info("File has errors (skipping): " + xtFile);
			return false;
		}
		
		if (!xtFile.wasModified() && !allowUnmodified)
		{
			log.info("File is not modified (skipping): " + xtFile);
			return false;
		}
		
		return true;
	}
	// -------------------------
	
	
}
