/**
	$Id: ProtocolLoader.java 4939 2009-05-20 05:45:22Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.Annotatable;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.Protocol;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for protocols. Protocols must be loaded as
	property nodes. It can't be a root node or a forward/reverse-loading 
	node. The property node itself is created as a property-loading node
	that loads the protocol parameters when asked to load it's children.
	
	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-05-20 07:45:22 +0200 (Wed, 20 May 2009) $
*/
public class ProtocolLoader
	extends BasicItemNodeLoader<Protocol>
{

	public ProtocolLoader()
	{
		super(Item.PROTOCOL, DENY_ROOT_NODE, 
				new NameableNameGenerator<Protocol>("protocol", "Protocol"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		Protocol protocol = null;
		boolean denied = false;
		try
		{
			BasicItem parentItem = parentNode.getItem(dc);
			if (parentItem instanceof Annotatable)
			{
				protocol = ((Annotatable)parentItem).getProtocol();
			}
			// If there are non-annotatable items with a protocol
			// we should add more cases here
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		
		NodeFactory<Protocol> nf = getNodeFactory(dc, context);
		Node protocolNode = createItemNode(nf, protocol, null, denied, 
				parentNode, ChildNodeDirection.PROPERTY);
		// NOTE! The protocol node can't be cached since validation results
		// for protocol parameters depend on the annotation on the parent
		// item. Eg. each use of a protocol is different
		return protocolNode;
	}
	// -----------------------------------
	/*
		From the AbstractNodeLoader class
		----------------------------------
	*/
	/**
		Loads annotations and protocol parameters for the given protocol node.
		@see RawBioAssayLoader#createForwardNode(DbControl, OverviewContext, Node)
	*/
	@Override
	protected void loadPropertyChildNodes(DbControl dc, OverviewContext context, Node protocolNode)
	{
		getNodeLoader(context, Item.ANNOTATION).createPropertyNode(dc, context, protocolNode);
		getNodeLoader(context, "PROTOCOL.PARAMETER").createPropertyNode(dc, context, protocolNode);
	}
	// -------------------------------------
}