/**
	$Id$

	Copyright (C) 2012 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.node;

import net.sf.basedb.core.BioPlate;
import net.sf.basedb.core.MeasuredBioMaterial;
import net.sf.basedb.util.overview.Node;

/**
	Name generator implementation for {@link BioPlate} items. The 
	implementation use the {@link NameableNameGenerator} but appends 
	the coordinate of the biomaterial if the parent node  is a 
	biomaterial node. Eg. <code>My plate [A2]</code>.
	
	@author Nicklas
	@since 3.2
	@base.modified $Date$
*/
public class BioPlateNameGenerator
	extends NameableNameGenerator<BioPlate>
{

	/**
		Create a new name generator.
		@param namePrefix The prefix to use in node names
		@param titlePrefix The prefix to use in node titles
	*/
	public BioPlateNameGenerator(String namePrefix, String titlePrefix)
	{
		super(namePrefix, titlePrefix);
	}
	
	/*
		From the NameableNameGenerator class
		------------------------------------
	*/
	/**
		The base of the title is generated by the superclass. This
		implementation adds a suffix to the title with the coordinate
		of the biomaterial if the parent node is a biomaterial node.
	*/
	@Override
	public String getNodeTitle(BioPlate item, Node parentNode)
	{
		String title = super.getNodeTitle(item, parentNode);
		try
		{
			if (parentNode.getItem() instanceof MeasuredBioMaterial)
			{
				MeasuredBioMaterial bm = (MeasuredBioMaterial)parentNode.getItem();
				title += " [" + bm.getBioWell().getCoordinate() + "]";
			}
		}
		catch (RuntimeException ex)
		{}
		return title;
	}
	// ------------------------
}
