/**
	$Id: ExperimentValidator.java 5651 2011-06-08 13:00:33Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.validator;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Experiment;
import net.sf.basedb.core.Project;
import net.sf.basedb.core.RawDataType;
import net.sf.basedb.util.overview.Fix;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.Node;

/**
	Validator implementation for experiments. Validation rules:
	<ul>
	<li>Non-default raw data type: {@link Validator#NONDEFAULT_RAWDATATYPE}
	</ul>

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2011-06-08 15:00:33 +0200 (Wed, 08 Jun 2011) $
*/
public class ExperimentValidator
	extends NameableNodeValidator<Experiment>
{
	
	public ExperimentValidator()
	{
		super(null, null);
	}
	
	/* 
		From BasicValidator class
		-------------------------
	*/
	@Override
	public void postValidate(DbControl dc, OverviewContext context, Node node, Node parentNode)
	{
		super.postValidate(dc, context, node, parentNode);
		Project project = context.getProject();
		Experiment experiment = (Experiment)node.getItem();
		if (project != null)
		{
			project = Project.getById(dc, project.getId());
			RawDataType projectDefault = project.getDefaultRawDataType();
			if (projectDefault != null && experiment.getRawDataType() != projectDefault)
			{
				context.createFailure(Validator.NONDEFAULT_RAWDATATYPE, node, null,
						new Fix("Change default raw data type of project", project)
					);
			}
		}
	}

	/**
		@return Always null
	*/
	@Override
	protected Fix getMissingItemFix(DbControl dc, Node parentNode)
	{
		return null;
	}
	// ----------------------------
}
