/**
	$Id: CropStringMapper.java 4515 2008-09-11 20:08:14Z jari $

	Copyright (C) 2006 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.parser;

import net.sf.basedb.util.parser.FlatFileParser.Data;

/**
 	A mapper that crops a string if it is longer than a specified
 	length. The actual mapping is delegated to a parent mapper.

	@author nicklas
	@version 2.0
	@base.modified $Date: 2008-09-11 22:08:14 +0200 (Thu, 11 Sep 2008) $
*/
public class CropStringMapper
	implements Mapper
{

	private final Mapper parent;
	private final int maxLength;
	
	/**
		Create a new CropStringMapper.
		@param parent The parent mapper that does the actual mapping
		@param maxLength The maximum length of stings
	*/
	public CropStringMapper(Mapper parent, int maxLength)
	{
		this.parent = parent;
		this.maxLength = maxLength;
	}

	/*
		From the Mapper interface
		-------------------------------------------
	*/
	/**
		Use the parent mapper to get the string value. Then check the
		length against the maximum length and crop if neccessary.
	*/
	public String getValue(Data data)
	{
		String s = parent.getValue(data);
		if (s != null && s.length() > maxLength) s = s.substring(0, maxLength);
		return s;
	}
	public Integer getInt(Data data)
	{
		return parent.getInt(data);
	}
	public Float getFloat(Data data)
	{
		return parent.getFloat(data);
	}
	// -------------------------------------------

}
