/*
	$Id: SpotImageCreator.java 5630 2011-05-13 12:54:50Z nicklas $

	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.plugins;

import net.sf.basedb.core.ProgressReporter;

import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Permission;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.File;
import net.sf.basedb.core.Path;
import net.sf.basedb.core.ItemAlreadyExistsException;
import net.sf.basedb.core.plugin.AbstractPlugin;
import net.sf.basedb.core.plugin.Permissions;
import net.sf.basedb.core.plugin.Plugin;
import net.sf.basedb.core.plugin.Request;
import net.sf.basedb.core.plugin.Response;
import net.sf.basedb.core.signal.SignalHandler;
import net.sf.basedb.core.signal.SignalTarget;
import net.sf.basedb.core.signal.ThreadSignalHandler;

import java.util.Arrays;
import java.util.Collection;
import java.util.EnumSet;
import java.util.HashSet;
import java.util.Set;

/**
   @author Nicklas
	@version 2.0
	@base.modified $Date: 2011-05-13 14:54:50 +0200 (Fri, 13 May 2011) $
*/
public class SpotImageCreator
	extends AbstractPlugin
	implements Plugin, SignalTarget  
{

	private static final Set<Permissions> permissions = new HashSet<Permissions>();

	private ThreadSignalHandler signalHandler;
	
	/*
		From the Plugin interface
		-------------------------------------------
	*/
	public Plugin.MainType getMainType()
	{
		return Plugin.MainType.OTHER;
	}
	public boolean supportsConfigurations()
	{
		return false;
	}
	public boolean requiresConfiguration()
	{
		return false;
	}
	/**
	 	Request write access to RawBioAssay:s, create and write access to File:s,
	 	use access to FileType:s and Directory:s.
	*/
	public Collection<Permissions> getPermissions()
	{
		if (permissions.size() == 0)
		{
			permissions.add(new Permissions(Item.RAWBIOASSAY, null, EnumSet.of(Permission.WRITE)));
			permissions.add(new Permissions(Item.FILE, null, EnumSet.of(Permission.CREATE, Permission.WRITE)));
			permissions.add(new Permissions(Item.ITEMSUBTYPE, EnumSet.of(Permission.USE), null));
			permissions.add(new Permissions(Item.DIRECTORY, null, EnumSet.of(Permission.USE)));
		}
		return permissions;
	}

	public void run(Request request, Response response, ProgressReporter progress)
	{
		DbControl dc = sc.newDbControl();
		try
		{
			RawBioAssay rawBioAssay = (RawBioAssay)job.getValue("rawBioAssay");
			rawBioAssay = RawBioAssay.getById(dc, rawBioAssay.getId());
			int xScale = (Integer)job.getValue("xScale");
			int yScale = (Integer)job.getValue("yScale");
			int xOffset = (Integer)job.getValue("xOffset");
			int yOffset = (Integer)job.getValue("yOffset");
			int spotsize = (Integer)job.getValue("spotsize");
			float gamma = (Float)job.getValue("gamma");
			float quality = (Float)job.getValue("quality");
			
			File red = (File)job.getValue("redFile");
			red = red == null ? null : File.getById(dc, red.getId());
			File green = (File)job.getValue("greenFile");
			green = green == null ? null : File.getById(dc, green.getId());
			File blue = (File)job.getValue("blueFile");
			blue = blue == null ? null : File.getById(dc, blue.getId());
			
			String path = (String)job.getValue("path");
			Boolean overwrite = (Boolean)job.getValue("overwrite");
			
			Path p = new Path(path, Path.Type.FILE);
			File saveAs = File.getByPath(dc, p, true);
			if (!saveAs.isInDatabase())
			{
				dc.saveItem(saveAs);
			}
			else if (!overwrite)
			{
				throw new ItemAlreadyExistsException("File[path="+path+"]");
			}

			rawBioAssay.getSpotImages().createSpotImages(saveAs, xScale, yScale, xOffset, yOffset, 
				spotsize, gamma, quality, red, green, blue, progress);
			
			dc.commit();
			response.setDone("Spot images generated successfully");
		}
		catch (Throwable t)
		{
			response.setError(t.getMessage(), Arrays.asList(t));
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}
	// -------------------------------------------
	/*
		From the SignalTarget interface
		-------------------------------------------
	*/
	public SignalHandler getSignalHandler()
	{
		signalHandler = new ThreadSignalHandler();
		return signalHandler;
	}
	// -------------------------------------------

}
