/**
	$Id: ConfigurableServiceFactory.java 4513 2008-09-11 20:06:36Z jari $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.ws.client;

import org.apache.axis2.AxisFault;
import org.apache.axis2.addressing.EndpointReference;
import org.apache.axis2.client.Options;
import org.apache.axis2.rpc.client.RPCServiceClient;

/**
	A service factory implementation that exposes the {@link 
	Options} object. 
	
	@author nicklas
	@version 2.8
	@base.modified $Date: 2008-09-11 22:06:36 +0200 (Thu, 11 Sep 2008) $
 */
public class ConfigurableServiceFactory
	implements ServiceFactory
{

	private Options options;
	
	/**
		Create a new service factory that uses the default options.
		Use {@link #setOptions(Options)} to specify other options.
	*/
	public ConfigurableServiceFactory()
	{}
	
	/**
		Create a new service factory that uses the given options.
	*/
	public ConfigurableServiceFactory(Options options)
	{
		this.options = options;
	}
	
	/*
		From the ServiceFactory interface
		---------------------------------------
	*/
	@Override
	public RPCServiceClient createService(EndpointReference target) 
		throws AxisFault
	{
		RPCServiceClient client = new RPCServiceClient();
		client.getOptions().setTo(target);
		if (options != null) client.setOverrideOptions(options);
		return client;
	}
	// ----------------------------------------
	
	/**
		Set the options to use when creating new {@link RPCServiceClient}
		objects with {@link #createService(EndpointReference)}.
		@param options The options, or null to use the default options
	*/
	public void setOptions(Options options)
	{
		this.options = options;
	}
	
	/**
		Get the currently active options that are used by the 
		{@link #createService(EndpointReference)} method.
		@return The options, or null if no options have been specified
	*/
	public Options getOptions()
	{
		return options;
	}
	
}
