<%-- $Id: calendar.jsp 6099 2012-09-03 13:33:54Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	A window for selecting a date interactively from a calendar

	@param title The title of the input field on the parent form
	@param form The name of the form where the input field is located
	@param input The name of the input field containing the current date value
	@param callback A javascript function to call to set the date in the
		opener's form (optional)

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.Date"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%
	final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
	String title = request.getParameter("title");
	String form = request.getParameter("form");
	String input = request.getParameter("input");
	String callback = request.getParameter("callback");
	boolean datetime = Values.getBoolean(request.getParameter("datetime"));
	String format = Values.getString(request.getParameter("format"), datetime ? "yyyy-MM-dd HH:mm:ss" : "yyyy-MM-dd");
	final float scale = Base.getScale(sc);
%>
<base:page type="popup" title="<%=title%>">
<base:head styles="calendar.css">
	<script language="JavaScript">

	var datetime = <%=datetime ? "1" : "0"%>;
	var dateFormat = '<%=HTML.javaScriptEncode(format)%>';
	var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
	var currentDate;
	
	var calendarYear;
	var calendarMonth;
	
	function init()
	{
		currentDate = getInitialDate();
		showFullDate(currentDate);
	}

	function getInitialDate()
	{
		var frm = window.opener.document.forms['<%=form%>'];
		var dateString = frm['<%=input%>'].value;
		var date = Dates.parseString(dateString, '<%=HTML.javaScriptEncode(format)%>');
		if (date == null) date = new Date();
		return date;
	}

	function saveCurrentDate(notime)
	{
		var frm = document.forms['calendar'];
		if (!validate())
		{
			return;
		}
		if (datetime && !notime)
		{
			currentDate.setHours(frm.hours.value);
			currentDate.setMinutes(frm.minutes.value);
			currentDate.setSeconds(frm.seconds.value);
		}
		var formattedDate = Dates.formatDate(currentDate, dateFormat);
		<%
		if (callback == null)
		{
			%>
			var frm = window.opener.document.forms['<%=form%>'];
			frm['<%=input%>'].value = formattedDate;
			<%
		}
		else
		{
			%>
			window.opener.<%=callback%>('<%=form%>', '<%=input%>', formattedDate);
			<%
		}
		%>
		window.close();
	}
	
	function showFullDate(date, notime)
	{
		calendarYear = date.getFullYear();
		calendarMonth = date.getMonth();
		
		var frm = document.forms['calendar'];
		// Update month and year
		document.getElementById('year').innerHTML = Dates.getFourDigitYear(date.getFullYear());
		document.getElementById('month').innerHTML = MONTHS[date.getMonth()];
		// Days in the month are displayed as a table
		displayMonth(date.getFullYear(), date.getMonth(), currentDate);
		// Time (if present) are regular input fields
		if (datetime && !notime)
		{
			frm.hours.value = zeroPad(date.getHours());
			frm.minutes.value = zeroPad(date.getMinutes());
			frm.seconds.value = zeroPad(date.getSeconds());
		}
	}
	
	function zeroPad(value)
	{
		return value <= 9 ? '0' + value : value;
	}

	function setDate(date)
	{
		currentDate.setFullYear(date.getFullYear());
		currentDate.setMonth(date.getMonth());
		currentDate.setDate(date.getDate());
		if (datetime)
		{
			showFullDate(currentDate, true);
		}
		else
		{
			saveCurrentDate();
		}
	}

	
	function setToday()
	{
		currentDate = new Date();
		saveCurrentDate(true);
	}
	
	function displayMonth(year, month, current)
	{
		var date = Dates.newDate(year, month, 1);
		var today = new Date();
		var firstDay = date.getDay();
		firstDay = firstDay == 0 ? 6 : firstDay - 1;
		var dayOfMonth = 1-firstDay;
		var daysInMonth = Dates.daysInMonth(year, month+1);
		for (var week = 1; week <= 6; week++) // >
		{
			for (var day = 0; day <= 6; day++) // >
			{
				var cell = document.getElementById('w'+week+'d'+day);
				if (dayOfMonth < 1 || dayOfMonth > daysInMonth)
				{
					cell.firstChild.nodeValue = '';
					cell.theDate = '';
					Main.removeClass(cell, 'validdate');
					cell.tabIndex = -1;
					if (day == 0 && week > 4) Main.hide('w' + week);
				}
				else
				{
					cell.firstChild.nodeValue = dayOfMonth;
					cell.theDate = Dates.newDate(year, month, dayOfMonth);
					Main.addClass(cell, 'validdate');
					cell.tabIndex = 0;
					if (day == 0) Main.show('w' + week);
				}
				if (year == today.getFullYear() && month == today.getMonth() && dayOfMonth == today.getDate())
				{
					Main.addClass(cell, 'today');
				}
				else
				{
					Main.removeClass(cell, 'today');
				}
				if (year == current.getFullYear() && month == current.getMonth() && dayOfMonth == current.getDate())
				{
					Main.addClass(cell, 'current');
					cell.focus();
				}
				else
				{
					Main.removeClass(cell, 'current');
				}
				dayOfMonth++;
			}
		}
	}
	
	function addToMonth(delta)
	{
		calendarMonth += delta;
		if (calendarMonth < 0) 
		{
			calendarMonth = 11;
			calendarYear--;
		}
		if (calendarMonth > 11) 
		{
			calendarMonth = 0;
			calendarYear++;
		}
		showFullDate(new Date(calendarYear, calendarMonth, 1));
	}
	
	function addToHour(delta)
	{
		var frm = document.forms['calendar'];
		var nextHour = parseInt(frm.hours.value, 10) + delta;
		if (nextHour < 0) nextHour = 0;
		if (nextHour > 23) nextHour = 23;
		frm.hours.value = zeroPad(nextHour);
	}

	function addToMinute(delta)
	{
		var frm = document.forms['calendar'];
		var nextMinute = parseInt(frm.minutes.value, 10) + delta;
		if (nextMinute < 0) nextMinute = 0;
		if (nextMinute > 59) nextMinute = 59;
		frm.minutes.value = zeroPad(nextMinute);
	}

	function addToSecond(delta)
	{
		var frm = document.forms['calendar'];
		var nextSecond = parseInt(frm.seconds.value, 10) + delta;
		if (nextSecond < 0) nextSecond = 0;
		if (nextSecond > 59) nextSecond = 59;
		frm.seconds.value = zeroPad(nextSecond);
	}

	function showError(message)
	{
		alert(message);
	}

	function validate()
	{
		var frm = document.forms['calendar'];
		if (datetime)
		{
			var hours = parseInt(frm.hours.value, 10);
			if (hours < 0 || hours > 23)
			{
				frm.hours.focus();
				showError('Hours must be a value between 0 and 23');
				return false;
			}
			var minutes = parseInt(frm.minutes.value, 10);
			if (minutes < 0 || minutes > 59)
			{
				frm.minutes.focus();
				showError('Minutes must be a value between 0 and 59');
				return false;
			}
			var seconds = parseInt(frm.seconds.value, 10);
			if (seconds < 0 || seconds > 59)
			{
				frm.seconds.focus();
				showError('Seconds must be a value between 0 and 59');
				return false;
			}
		}
		return true;
	}
	
	function handleFocusedKeypress(event, week, day)
	{
		var keyCode = Main.getEventKeyCode(event);
		var target = Main.getEventTarget(event);
		if (keyCode == 13)
		{
			// Delegate 'ENTER' to main handler
			Main.handleFocusedKeypress(event);
		}
		else if (keyCode >= 37 && keyCode <= 40)
		{
			// 37 - left, 38 - up, 39 - right, 40 - down
			if (keyCode == 37) day--;
			if (keyCode == 38) week--;
			if (keyCode == 39) day++;
			if (keyCode == 40) week++;
			var next = document.getElementById('w'+week+'d'+day);
			if (next && next.tabIndex != -1)
			{
				next.focus();
			}
		}
	}
	</script>
</base:head>
<base:body onload="init()">
	<h1><%=title%><base:help helpid="calendar.selectday" /></h1>
	<form name="calendar" onsubmit="return false;">
	<div class="content filled">

		<div style="position: absolute; top: 0px; left: 0px; right: 0px; height: 2em; text-align: center;">
			<table style="height: 100%; margin:auto;"><tr><td>
			<base:icon image="goback.png" onclick="addToMonth(-1)" />
			</td>
			<td style="width: 15em;">
			<b>
			<span id="month"></span>
			<span id="year"></span>
			</b>
			</td>
			<td>
			<base:icon image="gonext.png" onclick="addToMonth(1)"/>
			</td></tr></table>
		</div>

		
		<div style="position: absolute; top: 2em; bottom: 2em; width: 100%;">
		<table class="calendar">
		<tr>
			<td class="day">Mon</td>
			<td class="day">Tue</td>
			<td class="day">Wed</td>
			<td class="day">Thu</td>
			<td class="day">Fri</td>
			<td class="day">Sat</td>
			<td class="day">Sun</td>
		</tr>
		<%
		for (int week = 1; week < 7; ++week)
		{
			%>
			<tr id="w<%=week%>" style="max-height: 1.5em;">
			<%
			for (int day = 0; day < 7; ++day)
			{
				%>
				<td id="w<%=week%>d<%=day%>" 
					class="date <%=day==6 ? "sunday" : ""%>" 
					onclick="if (this.theDate) setDate(this.theDate)"
					onkeydown="handleFocusedKeypress(event, <%=week%>, <%=day%>)"
					tabindex="0"><%=day%></td>
				<%
			}
			%>
			</tr>
			<%
		}
		%>
		</table>
		</div>
		<%
		if (datetime)
		{
			%>
			<div style="position: absolute; height: 2em; left: 0px; right: 0px; bottom: 0em; text-align: center;">
			<table style="height: 100%; margin:auto;">
			<tr>
				<td class="time">Time</td>
				<td><input class="text" type="text" name="hours" title="Hours" size="2" maxlength="2" 
					onkeypress="return Numbers.integerOnly(event)"></td>
				<td style="width: 1.5em;">
					<table>
					<tr><td><base:icon image="mini_scroll_up.png" onclick="addToHour(1)" tooltip="Add one hour"/></td></tr>
					<tr><td><base:icon image="mini_scroll_down.png" onclick="addToHour(-1)" tooltip="Subtract one hour"/></td></tr>
					</table>
				</td>
				<td><input class="text" type="text" name="minutes" title="Minutes" size="2" maxlength="2" 
					onkeypress="return Numbers.integerOnly(event)"></td>
				<td style="width: 1.5em;">
					<table>
					<tr><td><base:icon image="mini_scroll_up.png" onclick="addToMinute(1)" tooltip="Add one minute"/></td></tr>
					<tr><td><base:icon image="mini_scroll_down.png" onclick="addToMinute(-1)" tooltip="Subtract one minute"/></td></tr>
					</table>
				</td>
				<td><input class="text" type="text" name="seconds" title="Seconds" size="2" maxlength="2" 
					onkeypress="return Numbers.integerOnly(event)"></td>
				<td style="width: 1.5em;">
					<table>
					<tr><td><base:icon image="mini_scroll_up.png" onclick="addToSecond(1)" tooltip="Add one second"/></td></tr>
					<tr><td><base:icon image="mini_scroll_down.png" onclick="addToSecond(-1)" tooltip="Subtract one second"/></td></tr>
					</table>
				</td>
			</tr>
			</table>
			</div>
			<%
		}
		%>
	</div>
	</form>
	
	
	<base:buttongroup subclass="dialogbuttons">
		<base:button image="today.png" onclick="setToday()" title="<%=datetime ? "Now" : "Today"%>" />
		<base:button onclick="saveCurrentDate()" title="Ok" visible="<%=datetime%>"/>
		<base:button onclick="window.close()" title="Cancel" />
	</base:buttongroup>
</base:body>
</base:page>
